@@ -1,5 +1,6 @@
 import mdtraj as md
 from mdtraj.testing import get_fn, eq, DocStringFormatTester, skipif
+import numpy as np
 
 try:
     from simtk.openmm import app
@@ -7,12 +8,14 @@ try:
 except ImportError:
     HAVE_OPENMM = False
 
+
 try:
     import pandas as pd
     HAVE_PANDAS = True
 except ImportError:
     HAVE_PANDAS = False
 
+
 @skipif(not HAVE_OPENMM)
 def test_topology_openmm():
     topology = md.load(get_fn('1bpi.pdb')).topology
@@ -30,8 +33,16 @@ def test_topology_pandas():
     topology2 = md.Topology.from_dataframe(atoms, bonds)
     eq(topology, topology2)
 
+
 def test_topology_numbers():
     topology = md.load(get_fn('1bpi.pdb')).topology
     assert len(list(topology.atoms)) == topology.n_atoms
     assert len(list(topology.residues)) == topology.n_residues
     assert all([topology.atom(i).index == i for i in range(topology.n_atoms)])
+
+@skipif(not HAVE_PANDAS)
+def test_topology_unique_elements_bpti():
+    traj = md.load(get_fn('bpti.pdb'))
+    top, bonds = traj.top.to_dataframe()
+    atoms = np.unique(["C", "O", "N", "H", "S"])
+    eq(atoms, np.unique(top.element.values))
