@@ -28,11 +28,11 @@ import numpy as np
 
 from mdtraj import (DCDTrajectoryFile, BINPOSTrajectoryFile, XTCTrajectoryFile,
                     TRRTrajectoryFile, HDF5TrajectoryFile, NetCDFTrajectoryFile,
-                    PDBTrajectoryFile, MDCRDTrajectoryFile, Topology)
+                    PDBTrajectoryFile, MDCRDTrajectoryFile, ArcTrajectoryFile, Topology)
 from mdtraj.utils import unitcell, ensure_type
 
 __all__ = ['Trajectory', 'load', 'load_pdb', 'load_xtc', 'load_trr', 'load_binpos',
-           'load_dcd', 'load_netcdf', 'load_hdf5', 'load_netcdf', 'load_xml']
+           'load_dcd', 'load_netcdf', 'load_hdf5', 'load_netcdf', 'load_arc', 'load_xml']
 
 ##############################################################################
 # Globals
@@ -655,6 +655,60 @@ def load_mdcrd(filename, top=None, stride=None, atom_indices=None):
         t.unitcell_angles = cell_angles
     return t
 
+def load_arc(filename, top=None, stride=None, atom_indices=None):
+    """Load a TINKER .arc file.
+
+    Parameters
+    ----------
+    filename : str
+        String filename of TINKER .arc file.
+    top : {str, Trajectory, Topology}
+        The .arc format does not contain topology information. Pass in either
+        the path to a pdb file, a trajectory, or a topology to supply this
+        information.
+    stride : int, default=None
+        Only read every stride-th frame
+    atom_indices : array_like, optional
+        If not none, then read only a subset of the atoms coordinates from the
+        file.
+
+    Returns
+    -------
+    trajectory : md.Trajectory
+        The resulting trajectory, as an md.Trajectory object.
+
+    See Also
+    --------
+    mdtraj.ArcTrajectoryFile :  Low level interface to TINKER .arc files
+    """
+    # we make it not required in the signature, but required here. although this
+    # is a little weird, its good because this function is usually called by a
+    # dispatch from load(), where top comes from **kwargs. So if its not supplied
+    # we want to give the user an informative error message
+    if top is None:
+        raise ValueError('"top" argument is required for load_arc')
+
+    if not isinstance(filename, basestring):
+        raise TypeError('filename must be of type string for load_arc. '
+            'you supplied %s' % type(filename))
+
+    topology = _parse_topology(top)
+    atom_indices = _cast_indices(atom_indices)
+    if atom_indices is not None:
+        topology = topology.subset(atom_indices)
+
+    with ArcTrajectoryFile(filename) as f:
+        xyz = f.read(stride=stride, atom_indices=atom_indices)
+        _convert(xyz, f.distance_unit, Trajectory._distance_unit, inplace=True)
+
+    time = np.arange(len(xyz))
+    if stride is not None:
+        # if we loaded with a stride, the Trajectories's time field should
+        # respect that
+        time *= stride
+
+    t = Trajectory(xyz=xyz, topology=topology, time=time)
+    return t
 
 def load_netcdf(filename, top=None, stride=None, atom_indices=None):
     """Load an AMBER NetCDF file. Since the NetCDF format doesn't contain
@@ -998,7 +1052,8 @@ class Trajectory(object):
     @xyz.setter
     def xyz(self, value):
         "Set the cartesian coordinates of each atom in each simulation frame"
-        if hasattr(self, 'topology'):
+        if getattr(self, 'topology', None) is not None:
+            # if we have a topology and its not None
             shape = (None, self.topology._numAtoms, 3)
         else:
             shape = (None, None, 3)
@@ -1022,9 +1077,11 @@ class Trajectory(object):
 
 
     def join(self, other, check_topology=True, discard_overlapping_frames=False):
-        """Join two trajectories together
+        """Join two trajectories together along the time/frame axis.
 
-        This method can also be called by using `self + other`
+        This method joins trajectories along the time axis, giving a new trajectory
+        of length equal to the sum of the lengths of `self` and `other`.
+        It can also be called by using `self + other`
 
         Parameters
         ----------
@@ -1037,6 +1094,10 @@ class Trajectory(object):
         discard_overlapping_frames : bool, optional
             If True, compare coordinates at trajectory edges to discard overlapping
             frames.  Default: False.
+
+        See Also
+        --------
+        stack : join two trajectories along the atom axis
         """
         if not isinstance(other, Trajectory):
             raise TypeError('You can only add two Trajectory instances')
@@ -1051,30 +1112,27 @@ class Trajectory(object):
 
         lengths2 = None
         angles2 = None
-        other_has_unitcell = (other.unitcell_lengths is not None and other.unitcell_angles is not None)
 
         if discard_overlapping_frames:
             x0 = self.xyz[-1]
-            x1 = other.xyz[-1]
-            if np.linalg.norm(x1 - x0) < 1e-8:
-                xyz = other.xyz[1:]
-                time = other.time[1:]
-                if other_has_unitcell:
-                    lengths2 = other.unitcell_lengths[1:]
-                    angles2 = other.unitcell_angles[1:]
-        else:
-            xyz = other.xyz
-            time = other.time
-            if other_has_unitcell:
-                lengths2 = other.unitcell_lengths
-                angles2 = other.unitcell_angles
+            x1 = other.xyz[0]
+            start_frame = 1 if np.linalg.norm(x1 - x0) < 1e-8 else 0
+        else: 
+            start_frame = 0
+
+        xyz = other.xyz[start_frame:]
+        time = other.time[start_frame:]
+        if other._have_unitcell:
+            lengths2 = other.unitcell_lengths[start_frame:]
+            angles2 = other.unitcell_angles[start_frame:]
 
         xyz = np.concatenate((self.xyz, xyz))
         time = np.concatenate((self.time, time))
 
-        if self.unitcell_lengths is None and self.unitcell_angles is None and not other_has_unitcell:
+        #if self.unitcell_lengths is None and self.unitcell_angles is None and not other_has_unitcell:
+        if not self._have_unitcell and not other._have_unitcell:
             lengths, angles = None, None
-        elif self.unitcell_lengths is not None and self.unitcell_angles is not None and other_has_unitcell:
+        elif self._have_unitcell and other._have_unitcell:
             lengths = np.concatenate((self.unitcell_lengths, lengths2))
             angles = np.concatenate((self.unitcell_angles, angles2))
         else:
@@ -1086,6 +1144,53 @@ class Trajectory(object):
         return self.__class__(xyz, deepcopy(self._topology), time=time,
             unitcell_lengths=lengths, unitcell_angles=angles)
 
+    def stack(self, other):
+        """Stack two trajectories along the atom axis
+
+        This method joins trajectories along the atom axis, giving a new trajectory
+        with a number of atoms equal to the sum of the number of atoms in
+        `self` and `other`.
+
+        Notes
+        -----
+        The resulting trajectory will have the unitcell and time information
+        the left operand.
+
+        Examples
+        --------
+        >>> t1 = md.load('traj1.h5')                            # doctest: +SKIP
+        >>> t2 = md.load('traj2.h5')                            # doctest: +SKIP
+        >>> # even when t2 contains no unitcell information
+        >>> t2.unitcell_vectors = None                          # doctest: +SKIP
+        >>> stacked = t1.stack(t2)                              # doctest: +SKIP
+        >>> # the stacked trajectory inherits the unitcell information
+        >>> # from the first trajectory
+        >>> np.all(stacked.unitcell_vectors == t1.unitcell_vectors) # doctest: +SKIP
+        True
+
+        Parameters
+        ----------
+        other : Trajectory
+            The other trajectory to join
+
+        See Also
+        --------
+        join : join two trajectories along the time/frame axis.
+        """
+        if not isinstance(other, Trajectory):
+            raise TypeError('You can only stack two Trajectory instances')
+        if self.n_frames != other.n_frames:
+            raise ValueError('Number of frames in self (%d) is not equal '
+                             'to number of frames in other (%d)' % (self.n_frames, other.n_frames))
+        if self.topology is not None:
+            topology = self.topology.join(other.topology)
+        else:
+            topology = None
+
+        xyz = np.hstack((self.xyz, other.xyz))
+        return self.__class__(xyz=xyz, topology=topology, unitcell_angles=self.unitcell_angles,
+                              unitcell_lengths=self.unitcell_lengths, time=self.time)
+
     def __getitem__(self, key):
         "Get a slice of this trajectory"
         return self.slice(key)
@@ -1143,8 +1248,8 @@ class Trajectory(object):
             time = np.arange(len(self.xyz))
         self.time = time
 
-        if not topology._numAtoms == self.n_atoms:
-            raise ValueError("Number of atoms in xyz (%s) and "
+        if (topology is not None) and (topology._numAtoms != self.n_atoms):
+             raise ValueError("Number of atoms in xyz (%s) and "
                 "in topology (%s) don't match" % (self.n_atoms, topology._numAtoms))
 
     def openmm_positions(self, frame):
@@ -1462,5 +1567,6 @@ _LoaderRegistry = {
     #'.lh5': _load_legacy_hdf,
     '.binpos': load_binpos,
     '.ncdf': load_netcdf,
-    '.nc': load_netcdf
+    '.nc': load_netcdf,
+    '.arc': load_arc
 }
